/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.risk;

import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.locationtech.jts.geom.Point;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/20 17:19
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Entity
@Table(name = "BS_RISK_WARN", uniqueConstraints = @UniqueConstraint(columnNames = { "locationNum" }))
@Comment("风险预警")
public class RiskWarn extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 1345477064611048638L;

    //todo 工区

    @Comment("安装位置")
    private String install;

    @Comment("经纬度")
    @Column(columnDefinition = "geometry(Point,4326)")
    private Point point;

    @Comment("监控参数")
    private String monitoring;

    @Comment("位号")
    private String locationNum;

    @Comment("量程起始值")
    private Integer min;

    @Comment("量程结束值")
    private Integer max;

    @Comment("量程单位")
    private String unit;

    @Comment("启用")
    private Boolean enable;

    @Builder.Default
    @OneToMany(mappedBy = "riskWarn")
    @ToString.Exclude
    private Set<Threshold> thresholds = new HashSet<>();
}
